@@ -969,6 +969,7 @@ static void redraw_screen(struct terminal *term)
 	int l = 0;
 	int print_next = 0;
 	struct term_spec *s;
+	n_chars = n_chars + 0;	/* avoid warning */
 	NO_GFX;
 	if (!term->dirty || (term->master && is_blocked())) return;
 	a = init_str();
@@ -1334,14 +1335,14 @@ void exec_on_terminal(struct terminal *term, unsigned char *path, unsigned char
 	int rs;
 	if (path && !*path) return;
 	if (!path) path = cast_uchar "";
-#ifdef NO_FG_EXEC
-	fg = 0;
-#endif
 #ifdef HAVE_EXE_ON_BACKGROUND
 	if (*path) {
-		rs = exe_on_background(path, delet);
+		rs = exe_on_background(path, delet, fg);
 		if (!rs) return;
 	}
+#endif
+#ifdef NO_FG_EXEC
+	fg = 0;
 #endif
 	if (term->master) {
 		if (!*path) {
